AggregationIntervalPigeon class

Splits a date range into windows of seconds length; each window's records are reduced with aggregation.

Constructors

AggregationIntervalPigeon({required int seconds, required AggregationPigeon aggregation})

Properties

aggregation ↔ AggregationPigeon
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds ↔ int
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → AggregationIntervalPigeon