AudienceServiceApi class

API for Audience Service operations

Constructors

AudienceServiceApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Constructor for AudienceServiceApi. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
pigeonVar_binaryMessenger BinaryMessenger?
final
pigeonVar_messageChannelSuffix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSegmentDefinition(String name) Future<Object?>
Returns a single segment definition by its name, or null if not found
getSegmentDefinitions() Future<List<Object?>>
Returns all segment definitions as a JSON-like array
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
syncAudiences() Future<void>
Synchronizes audiences with the Orchestrator
syncSegmentDefinitions() Future<void>
Synchronizes segment definitions with the Orchestrator
syncSegmentSubscriptions() Future<void>
Synchronizes segment subscriptions with the backend
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>