BackupServiceApi class

API for Backup Service operations

Constructors

BackupServiceApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Constructor for BackupServiceApi. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
pigeonVar_binaryMessenger BinaryMessenger?
final
pigeonVar_messageChannelSuffix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createBackup() Future<String?>
Create a backup and return it as a JSON string
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore(String json) Future<void>
Restore from a backup JSON string
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>