DataSapienApi class

Main API for DataSapien SDK operations

Constructors

DataSapienApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
Constructor for DataSapienApi. The binaryMessenger named argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.

Properties

hashCode int
The hash code for this object.
no setterinherited
pigeonVar_binaryMessenger BinaryMessenger?
final
pigeonVar_messageChannelSuffix String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

initialize(DataSapienConfigPigeon config) Future<void>
Initialize the DataSapien SDK with the provided configuration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setup() Future<void>
Setup the SDK (async operation that syncs data)
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

pigeonChannelCodec → const MessageCodec<Object?>