DataSapienConfigPigeon class

Configuration class for DataSapien SDK initialization (Pigeon-generated)

Constructors

DataSapienConfigPigeon({required String authUrl, required String authClientId, required String authClientSecret, required String authScope, required String hostUrl, required String mediaUrl, String? mainColor, bool? debug})

Properties

authClientId String
getter/setter pair
authClientSecret String
getter/setter pair
authScope String
getter/setter pair
authUrl String
getter/setter pair
debug bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hostUrl String
getter/setter pair
mainColor String?
getter/setter pair
mediaUrl String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) DataSapienConfigPigeon