InferenceParamsPigeon class

Pigeon class for InferenceParams

Constructors

InferenceParamsPigeon({double? temperature, int? maxTokens, int? seed, double? topP, int? topK, LlamaGrammarConfigPigeon? grammarConfig})

Properties

grammarConfig ↔ LlamaGrammarConfigPigeon?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxTokens ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seed ↔ int?
getter/setter pair
temperature ↔ double?
getter/setter pair
topK ↔ int?
getter/setter pair
topP ↔ double?
getter/setter pair

Methods

encode() → Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(Object result) → InferenceParamsPigeon