JourneyServiceApi class
API for Journey Service operations
Constructors
- JourneyServiceApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
-
Constructor for JourneyServiceApi. The
binaryMessengernamed argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pigeonVar_binaryMessenger → BinaryMessenger?
-
final
- pigeonVar_messageChannelSuffix → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getJourney(
String name) → Future< Object?> - Returns a single journey by its name.
-
getJourneyExecutionRecords(
String name) → Future< List< Object?> ?> - Returns journey execution records for a journey.
-
getJourneys(
List< String?> tags, List<String?> statuses, bool? onlyInAudience) → Future<List< Object?> > - Returns journeys filtered by tags and statuses.
-
getJourneyStatus(
String name) → Future< String?> - Returns the current status of a journey.
-
getLastJourneyExecutionRecord(
String name) → Future< Object?> - Returns the latest journey execution record for a journey.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runJourney(
String name, Map< String?, Object?> ? data) → Future<Map< String?, Object?> > - Runs a journey by name with optional context data.
-
syncJourneys(
) → Future< void> - Synchronizes journey definitions with the Orchestrator.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
pigeonChannelCodec
→ const MessageCodec<
Object?>