ManagedAPIServiceApi class
API for Managed API Service operations
Constructors
- ManagedAPIServiceApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
-
Constructor for ManagedAPIServiceApi. The
binaryMessengernamed argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pigeonVar_binaryMessenger → BinaryMessenger?
-
final
- pigeonVar_messageChannelSuffix → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getManagedAPI(
String name) → Future< Object?> - Returns a single managed API by name as a map, or null if not found
-
getManagedAPIs(
) → Future< List< Object?> > - Returns all available managed APIs as a list of maps
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
syncManagedAPIs(
) → Future< void> - Synchronizes managed APIs from the backend
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
pigeonChannelCodec
→ const MessageCodec<
Object?>