MeDataServiceApi class
API for MeDataService operations
This interface mirrors the documented MeDataService API surface (methods and parameters) used by the JS/Android/iOS SDKs.
Constructors
- MeDataServiceApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
-
Constructor for MeDataServiceApi. The
binaryMessengernamed argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pigeonVar_binaryMessenger → BinaryMessenger?
-
final
- pigeonVar_messageChannelSuffix → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
collectMeData(
List< String?> meDataDefinitionNames) → Future<Map< String?, Object?> > - Triggers MeData collectors for the given definition names and returns a key–value map of definition name to collected data.
-
getAggregatedMeDataRecords(
String name, double startDate, double endDate, String aggregation, int? intervalSeconds, String? intervalAggregation) → Future< Object?> - Returns aggregated MeData records for the given definition.
-
getLastMeDataRecord(
String name) → Future< Object?> - Returns the most recent MeData record for the given definition name, or null if there is no record.
-
getMeDataCategories(
) → Future< List< Object?> ?> - Returns all MeData categories as an array, or null if no categories are available.
-
getMeDataDefinition(
String name) → Future< Object?> - Returns a single MeData definition by its name, or null if it is not found.
-
getMeDataDefinitions(
) → Future< List< Object?> > - Returns all MeData definitions as a JSON-like array.
-
getMeDataDefinitionsByCategory(
String name) → Future< List< Object?> ?> - Returns MeData definitions for the given category name, or null if none exist.
-
getMeDataRecords(
String name) → Future< List< Object?> ?> - Returns all stored records for the given MeData definition name, or null if no records exist.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveMeDataRecord(
String name, Object? values) → Future< void> - Saves a new MeData record for the given definition name with the provided values.
-
syncMeDataDefinitions(
) → Future< void> - Synchronizes MeData definitions with the Orchestrator and updates local storage.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
pigeonChannelCodec
→ const MessageCodec<
Object?>