ModelParamsPigeon class
Pigeon class for ModelParams
Constructors
- ModelParamsPigeon({int? nCtx, int? nBatchSize, int? nThreads, int? nGpuLayers})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nBatchSize ↔ int?
-
getter/setter pair
- nCtx ↔ int?
-
getter/setter pair
- nGpuLayers ↔ int?
-
getter/setter pair
- nThreads ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → ModelParamsPigeon