PromptPigeon class
Pigeon class for Prompt
Constructors
- PromptPigeon({required String role, required String content, String? attachment})
Properties
- attachment ↔ String?
-
getter/setter pair
- content ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- role ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encode(
) → Object -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Object result) → PromptPigeon