IntelligenceServiceApi class
API for Intelligence Service operations
Constructors
- IntelligenceServiceApi({BinaryMessenger? binaryMessenger, String messageChannelSuffix = ''})
-
Constructor for IntelligenceServiceApi. The
binaryMessengernamed argument is available for dependency injection. If it is left null, the default BinaryMessenger will be used which routes to the host platform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pigeonVar_binaryMessenger → BinaryMessenger?
-
final
- pigeonVar_messageChannelSuffix → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteModelFiles(
String name) → Future< void> - Delete downloaded model files
-
downloadModelFiles(
String name) → Future< void> - Download model files (progress callback not supported in Pigeon)
-
getDownloadedModelsList(
) → Future< List< String?> > - Get list of downloaded model names
-
getManagedAIModel(
String name) → Future< Object?> - Get a single managed AI model by name
-
getManagedAIModels(
) → Future< List< Object?> > - Get all managed AI models
-
getRule(
String name) → Future< Object?> - Get a single rule by name
-
getRules(
) → Future< List< Object?> > - Get all rules
-
invokeModel(
String name, List< PromptPigeon?> prompts, InferenceParamsPigeon? inferenceParams) → Future<String> - Invoke a model with prompts (streaming not supported, returns final result)
-
isModelFilesDownloaded(
String name) → Future< bool> - Check if model files are downloaded
-
loadModel(
String name, ModelParamsPigeon? modelParams) → Future< void> - Load a model with optional parameters
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runRule(
String name) → Future< Object?> - Run a specific rule by name
-
runRules(
bool onlyOnInit) → Future< List< Object?> > - Run all rules (optionally only those marked for init)
-
syncManagedAIModels(
) → Future< void> - Synchronize managed AI models from the backend
-
syncRules(
) → Future< void> - Synchronize rules from the backend
-
toString(
) → String -
A string representation of this object.
inherited
-
unloadModel(
) → Future< void> - Unload the currently loaded model
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
pigeonChannelCodec
→ const MessageCodec<
Object?>